pub struct RentalTransactionEvent {
pub amazon_order_id: Option<String>,
pub rental_event_type: Option<String>,
pub extension_length: Option<i32>,
pub posted_date: Option<String>,
pub rental_charge_list: Option<Vec<ChargeComponent>>,
pub rental_fee_list: Option<Vec<FeeComponent>>,
pub marketplace_name: Option<String>,
pub rental_initial_value: Option<Box<Currency>>,
pub rental_reimbursement: Option<Box<Currency>>,
pub rental_tax_withheld_list: Option<Vec<TaxWithheldComponent>>,
}Expand description
RentalTransactionEvent : An event related to a rental transaction.
Fields
amazon_order_id: Option<String>An Amazon-defined identifier for an order.
rental_event_type: Option<String>The type of rental event. Possible values: * RentalCustomerPayment-Buyout - Transaction type that represents when the customer wants to buy out a rented item. * RentalCustomerPayment-Extension - Transaction type that represents when the customer wants to extend the rental period. * RentalCustomerRefund-Buyout - Transaction type that represents when the customer requests a refund for the buyout of the rented item. * RentalCustomerRefund-Extension - Transaction type that represents when the customer requests a refund over the extension on the rented item. * RentalHandlingFee - Transaction type that represents the fee that Amazon charges sellers who rent through Amazon. * RentalChargeFailureReimbursement - Transaction type that represents when Amazon sends money to the seller to compensate for a failed charge. * RentalLostItemReimbursement - Transaction type that represents when Amazon sends money to the seller to compensate for a lost item.
extension_length: Option<i32>The number of days that the buyer extended an already rented item. This value is only returned for RentalCustomerPayment-Extension and RentalCustomerRefund-Extension events.
posted_date: Option<String>rental_charge_list: Option<Vec<ChargeComponent>>A list of charge information on the seller’s account.
rental_fee_list: Option<Vec<FeeComponent>>A list of fee component information.
marketplace_name: Option<String>The name of the marketplace.
rental_initial_value: Option<Box<Currency>>rental_reimbursement: Option<Box<Currency>>rental_tax_withheld_list: Option<Vec<TaxWithheldComponent>>A list of information about taxes withheld.
Implementations
sourceimpl RentalTransactionEvent
impl RentalTransactionEvent
sourcepub fn new() -> RentalTransactionEvent
pub fn new() -> RentalTransactionEvent
An event related to a rental transaction.